@@ -27,6 +27,7 @@ import org.apache.flink.connector.base.DeliveryGuarantee;
 import org.apache.flink.connector.kafka.sink.KafkaPartitioner;
 import org.apache.flink.connector.kafka.sink.KafkaSink;
 import org.apache.flink.connector.kafka.sink.KafkaSinkBuilder;
+import org.apache.flink.connector.kafka.sink.TransactionNamingStrategy;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.datastream.DataStreamSink;
 import org.apache.flink.table.api.DataTypes;
@@ -139,6 +140,8 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
     /** Parallelism of the physical Kafka producer. * */
     protected final @Nullable Integer parallelism;
 
+    private final TransactionNamingStrategy transactionNamingStrategy;
+
     public KafkaDynamicSink(
             DataType consumedDataType,
             DataType physicalDataType,
@@ -155,7 +158,8 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
             boolean upsertMode,
             SinkBufferFlushMode flushMode,
             @Nullable Integer parallelism,
-            @Nullable String transactionalIdPrefix) {
+            @Nullable String transactionalIdPrefix,
+            TransactionNamingStrategy transactionNamingStrategy) {
         // Format attributes
         this.consumedDataType =
                 checkNotNull(consumedDataType, "Consumed data type must not be null.");
@@ -168,6 +172,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
         this.valueProjection = checkNotNull(valueProjection, "Value projection must not be null.");
         this.keyPrefix = keyPrefix;
         this.transactionalIdPrefix = transactionalIdPrefix;
+        this.transactionNamingStrategy = transactionNamingStrategy;
         // Mutable attributes
         this.metadataKeys = Collections.emptyList();
         // Kafka-specific attributes
@@ -222,6 +227,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                                         hasMetadata(),
                                         getMetadataPositions(physicalChildren),
                                         upsertMode))
+                        .setTransactionNamingStrategy(transactionNamingStrategy)
                         .build();
         if (flushMode.isEnabled() && upsertMode) {
             return new DataStreamSinkProvider() {
@@ -292,7 +298,8 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                         upsertMode,
                         flushMode,
                         parallelism,
-                        transactionalIdPrefix);
+                        transactionalIdPrefix,
+                        transactionNamingStrategy);
         copy.metadataKeys = metadataKeys;
         return copy;
     }
@@ -358,7 +365,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
             Context context, ExecutionConfig executionConfig) {
         final TypeInformation<RowData> typeInformation =
                 context.createTypeInformation(consumedDataType);
-        return typeInformation.createSerializer(executionConfig);
+        return typeInformation.createSerializer(executionConfig.getSerializerConfig());
     }
 
     private int[] getMetadataPositions(List<LogicalType> physicalChildren) {
