@@ -17,6 +17,10 @@
 
 package org.apache.flink.connector.kafka.sink;
 
+import org.apache.flink.configuration.Configuration;
+import org.apache.flink.connector.kafka.sink.internal.FlinkKafkaInternalProducer;
+import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
+import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.util.TestLoggerExtension;
 
 import org.apache.kafka.clients.CommonClientConfigs;
@@ -30,10 +34,13 @@ import org.apache.kafka.common.errors.InvalidTxnStateException;
 import org.apache.kafka.common.errors.ProducerFencedException;
 import org.apache.kafka.common.serialization.StringDeserializer;
 import org.apache.kafka.common.serialization.StringSerializer;
+import org.assertj.core.api.AbstractThrowableAssert;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.extension.RegisterExtension;
 import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.CsvSource;
 import org.junit.jupiter.params.provider.MethodSource;
 import org.testcontainers.containers.KafkaContainer;
 import org.testcontainers.junit.jupiter.Container;
@@ -49,12 +56,22 @@ import java.util.stream.Collectors;
 import static org.apache.flink.connector.kafka.testutils.KafkaUtil.checkProducerLeak;
 import static org.apache.flink.connector.kafka.testutils.KafkaUtil.createKafkaContainer;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatCode;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 @Testcontainers
 @ExtendWith(TestLoggerExtension.class)
 class FlinkKafkaInternalProducerITCase {
 
+    @RegisterExtension
+    public static final MiniClusterExtension MINI_CLUSTER_RESOURCE =
+            new MiniClusterExtension(
+                    new MiniClusterResourceConfiguration.Builder()
+                            .setNumberTaskManagers(2)
+                            .setNumberSlotsPerTaskManager(8)
+                            .setConfiguration(new Configuration())
+                            .build());
+
     @Container
     private static final KafkaContainer KAFKA_CONTAINER =
             createKafkaContainer(FlinkKafkaInternalProducerITCase.class).withEmbeddedZookeeper();
@@ -65,14 +82,15 @@ class FlinkKafkaInternalProducerITCase {
     }
 
     @Test
-    void testInitTransactionId() {
+    void testResetTransactional() {
         final String topic = "test-init-transactions";
         final String transactionIdPrefix = "testInitTransactionId-";
         try (FlinkKafkaInternalProducer<String, String> reuse =
                 new FlinkKafkaInternalProducer<>(getProperties(), "dummy")) {
             int numTransactions = 20;
             for (int i = 1; i <= numTransactions; i++) {
-                reuse.initTransactionId(transactionIdPrefix + i);
+                reuse.setTransactionId(transactionIdPrefix + i);
+                reuse.initTransactions();
                 reuse.beginTransaction();
                 reuse.send(new ProducerRecord<>(topic, "test-value-" + i));
                 if (i % 2 == 0) {
@@ -100,7 +118,7 @@ class FlinkKafkaInternalProducerITCase {
             producer.beginTransaction();
             producer.send(new ProducerRecord<>(topic, "test-value"));
             producer.flush();
-            snapshottedCommittable = KafkaCommittable.of(producer, ignored -> {});
+            snapshottedCommittable = KafkaCommittable.of(producer);
         }
 
         try (FlinkKafkaInternalProducer<String, String> resumedProducer =
@@ -121,7 +139,7 @@ class FlinkKafkaInternalProducerITCase {
                 new FlinkKafkaInternalProducer<>(getProperties(), "dummy")) {
             producer.initTransactions();
             producer.beginTransaction();
-            snapshottedCommittable = KafkaCommittable.of(producer, ignored -> {});
+            snapshottedCommittable = KafkaCommittable.of(producer);
         }
 
         try (FlinkKafkaInternalProducer<String, String> resumedProducer =
@@ -159,6 +177,51 @@ class FlinkKafkaInternalProducerITCase {
         }
     }
 
+    @ParameterizedTest
+    @CsvSource({"true,true", "true,false", "false,true", "false,false"})
+    void testDoubleCommitAndAbort(boolean firstCommit, boolean secondCommit) {
+        final String topic = "test-double-commit-transaction-" + firstCommit + secondCommit;
+        final String transactionIdPrefix = "testDoubleCommitTransaction-";
+        final String transactionalId = transactionIdPrefix + "id";
+
+        KafkaCommittable committable;
+        try (FlinkKafkaInternalProducer<String, String> producer =
+                new FlinkKafkaInternalProducer<>(getProperties(), transactionalId)) {
+            producer.initTransactions();
+            producer.beginTransaction();
+            producer.send(new ProducerRecord<>(topic, "test-value"));
+            producer.flush();
+            committable = KafkaCommittable.of(producer);
+            if (firstCommit) {
+                producer.commitTransaction();
+            } else {
+                producer.abortTransaction();
+            }
+        }
+
+        try (FlinkKafkaInternalProducer<String, String> resumedProducer =
+                new FlinkKafkaInternalProducer<>(getProperties(), transactionalId)) {
+            resumedProducer.resumeTransaction(committable.getProducerId(), committable.getEpoch());
+            AbstractThrowableAssert<?, ? extends Throwable> secondOp =
+                    assertThatCode(
+                            () -> {
+                                if (secondCommit) {
+                                    resumedProducer.commitTransaction();
+                                } else {
+                                    resumedProducer.abortTransaction();
+                                }
+                            });
+            if (firstCommit == secondCommit) {
+                secondOp.doesNotThrowAnyException();
+            } else {
+                secondOp.isInstanceOf(InvalidTxnStateException.class);
+            }
+        }
+
+        assertNumTransactions(1, transactionIdPrefix);
+        assertThat(readRecords(topic).count()).isEqualTo(firstCommit ? 1 : 0);
+    }
+
     private static Properties getProperties() {
         Properties properties = new Properties();
         properties.put(
