@@ -46,10 +46,9 @@ import org.apache.kafka.common.TopicPartition;
 import org.apache.kafka.common.errors.UnknownTopicOrPartitionException;
 import org.assertj.core.api.Assertions;
 import org.assertj.core.api.ThrowingConsumer;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.time.Duration;
 import java.time.Instant;
@@ -83,29 +82,22 @@ import static org.assertj.core.api.Assertions.fail;
 import static org.assertj.core.api.HamcrestCondition.matching;
 
 /** Basic IT cases for the Kafka table source and sink. */
-@RunWith(Parameterized.class)
-public class KafkaTableITCase extends KafkaTableTestBase {
+class KafkaTableITCase extends KafkaTableTestBase {
 
-    private static final String JSON_FORMAT = "json";
-    private static final String AVRO_FORMAT = "avro";
-    private static final String CSV_FORMAT = "csv";
-
-    @Parameterized.Parameter public String format;
-
-    @Parameterized.Parameters(name = "format = {0}")
-    public static Collection<String> parameters() {
-        return Arrays.asList(JSON_FORMAT, AVRO_FORMAT, CSV_FORMAT);
+    private static Collection<String> formats() {
+        return Arrays.asList("avro", "csv", "json");
     }
 
-    @Before
-    public void before() {
+    @BeforeEach
+    void before() {
         // we have to use single parallelism,
         // because we will count the messages in sink to terminate the job
         env.setParallelism(1);
     }
 
-    @Test
-    public void testKafkaSourceSink() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSink(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "tstopic_" + format + "_" + UUID.randomUUID();
@@ -138,7 +130,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
 
         tEnv.executeSql(createTable);
 
@@ -195,8 +187,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithTopicList() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithTopicList(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic1 = "topics1_" + format + "_" + UUID.randomUUID();
@@ -230,7 +223,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         String.join(";", Arrays.asList(topic1, topic2)),
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
         final String createTopic1Table =
                 String.format(
                         createTableTemplate,
@@ -239,7 +232,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic1,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
         final String createTopic2Table =
                 String.format(
                         createTableTemplate,
@@ -248,7 +241,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic2,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
 
         tEnv.executeSql(createTopicListTable);
         tEnv.executeSql(createTopic1Table);
@@ -276,8 +269,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic2);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithTopicPattern() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithTopicPattern(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic1 = "topics1_" + format + "_" + UUID.randomUUID();
@@ -312,7 +306,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topicPattern,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
         final String createTopic1Table =
                 String.format(
                         createTableTemplate,
@@ -321,7 +315,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic1,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
         final String createTopic2Table =
                 String.format(
                         createTableTemplate,
@@ -330,7 +324,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic2,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
 
         tEnv.executeSql(createTopicPatternTable);
         tEnv.executeSql(createTopic1Table);
@@ -359,8 +353,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic2);
     }
 
-    @Test
-    public void testExactlyOnceSink() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testExactlyOnceSink(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "topics_" + format + "_" + UUID.randomUUID();
@@ -391,7 +386,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         TransactionNamingStrategy.POOLING,
                         topic,
                         bootstraps,
-                        formatOptions()));
+                        formatOptions(format)));
 
         List<Row> values =
                 Arrays.asList(Row.of(1, 1102, "behavior 1"), Row.of(2, 1103, "behavior 2"));
@@ -408,8 +403,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceEmptyResultOnDeletedOffsets() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceEmptyResultOnDeletedOffsets(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "bounded_" + format + "_" + UUID.randomUUID();
@@ -439,7 +435,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
         tEnv.executeSql(createTable);
         List<Row> values =
                 Arrays.asList(
@@ -464,8 +460,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithBoundedSpecificOffsets() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithBoundedSpecificOffsets(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "bounded_" + format + "_" + UUID.randomUUID();
@@ -495,7 +492,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
 
         tEnv.executeSql(createTable);
 
@@ -518,8 +515,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithBoundedTimestamp() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithBoundedTimestamp(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "bounded_" + format + "_" + UUID.randomUUID();
@@ -550,7 +548,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         topic,
                         bootstraps,
                         groupId,
-                        formatOptions());
+                        formatOptions(format));
 
         tEnv.executeSql(createTable);
 
@@ -575,8 +573,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaTableWithMultipleTopics() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaTableWithMultipleTopics(final String format) throws Exception {
         // ---------- create source and sink tables -------------------
         String tableTemp =
                 "create table %s (\n"
@@ -614,7 +613,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                                             topics.get(index),
                                             bootstraps,
                                             groupId,
-                                            formatOptions()));
+                                            formatOptions(format)));
                         });
         // create source table
         tEnv.executeSql(
@@ -625,7 +624,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                         String.join(";", topics),
                         bootstraps,
                         groupId,
-                        formatOptions()));
+                        formatOptions(format)));
 
         // ---------- Prepare data in Kafka topics -------------------
         String insertTemp =
@@ -668,8 +667,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         topics.forEach(super::deleteTestTopic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithMetadata() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithMetadata(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "metadata_topic_" + format + "_" + UUID.randomUUID();
@@ -701,7 +701,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
                                 + "  'scan.startup.mode' = 'earliest-offset',\n"
                                 + "  %s\n"
                                 + ")",
-                        topic, bootstraps, groupId, formatOptions());
+                        topic, bootstraps, groupId, formatOptions(format));
         tEnv.executeSql(createTable);
 
         String initialValues =
@@ -760,8 +760,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithKeyAndPartialValue() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithKeyAndPartialValue(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "key_partial_value_topic_" + format + "_" + UUID.randomUUID();
@@ -841,8 +842,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithKeyAndFullValue() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithKeyAndFullValue(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "key_full_value_topic_" + format + "_" + UUID.randomUUID();
@@ -919,8 +921,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testKafkaTemporalJoinChangelog() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaTemporalJoinChangelog(final String format) throws Exception {
         // Set the session time zone to UTC, because the next `METADATA FROM
         // 'value.source.timestamp'` DDL
         // will use the session time zone when convert the changelog time from milliseconds to
@@ -1062,8 +1065,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         tEnv.executeSql(insertSql).await();
     }
 
-    @Test
-    public void testPerPartitionWatermarkKafka() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testPerPartitionWatermarkKafka(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "per_partition_watermark_topic_" + format + "_" + UUID.randomUUID();
@@ -1152,8 +1156,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testPerPartitionWatermarkWithIdleSource() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testPerPartitionWatermarkWithIdleSource(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "idle_partition_watermark_topic_" + format + "_" + UUID.randomUUID();
@@ -1227,8 +1232,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testLatestOffsetStrategyResume() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testLatestOffsetStrategyResume(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "latest_offset_resume_topic_" + format + "_" + UUID.randomUUID();
@@ -1359,19 +1365,22 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         cleanupTopic(topic);
     }
 
-    @Test
-    public void testStartFromGroupOffsetsLatest() throws Exception {
-        testStartFromGroupOffsets("latest");
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testStartFromGroupOffsetsLatest(final String format) throws Exception {
+        testStartFromGroupOffsets("latest", format);
     }
 
-    @Test
-    public void testStartFromGroupOffsetsEarliest() throws Exception {
-        testStartFromGroupOffsets("earliest");
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testStartFromGroupOffsetsEarliest(final String format) throws Exception {
+        testStartFromGroupOffsets("earliest", format);
     }
 
-    @Test
-    public void testStartFromGroupOffsetsNone() {
-        Assertions.assertThatThrownBy(() -> testStartFromGroupOffsetsWithNoneResetStrategy())
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testStartFromGroupOffsetsNone(final String format) {
+        Assertions.assertThatThrownBy(() -> testStartFromGroupOffsetsWithNoneResetStrategy(format))
                 .satisfies(anyCauseMatches(NoOffsetForPartitionException.class));
     }
 
@@ -1402,7 +1411,12 @@ public class KafkaTableITCase extends KafkaTableTestBase {
     }
 
     private TableResult startFromGroupOffset(
-            String tableName, String topic, String groupId, String resetStrategy, String sinkName)
+            String tableName,
+            String topic,
+            String groupId,
+            String resetStrategy,
+            String sinkName,
+            String format)
             throws ExecutionException, InterruptedException {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
@@ -1467,7 +1481,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         return tEnv.executeSql("INSERT INTO " + sinkName + " SELECT * FROM " + tableName);
     }
 
-    private void testStartFromGroupOffsets(String resetStrategy) throws Exception {
+    private void testStartFromGroupOffsets(String resetStrategy, String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String tableName = "Table" + format + resetStrategy;
@@ -1481,7 +1495,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
 
         TableResult tableResult = null;
         try {
-            tableResult = startFromGroupOffset(tableName, topic, groupId, resetStrategy, sinkName);
+            tableResult =
+                    startFromGroupOffset(
+                            tableName, topic, groupId, resetStrategy, sinkName, format);
             if ("latest".equals(resetStrategy)) {
                 expected = appendNewData(topic, tableName, groupId, expected.size());
             }
@@ -1493,7 +1509,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         }
     }
 
-    private void testStartFromGroupOffsetsWithNoneResetStrategy()
+    private void testStartFromGroupOffsetsWithNoneResetStrategy(final String format)
             throws ExecutionException, InterruptedException {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
@@ -1504,7 +1520,9 @@ public class KafkaTableITCase extends KafkaTableTestBase {
 
         TableResult tableResult = null;
         try {
-            tableResult = startFromGroupOffset(tableName, topic, groupId, resetStrategy, "MySink");
+            tableResult =
+                    startFromGroupOffset(
+                            tableName, topic, groupId, resetStrategy, "MySink", format);
             tableResult.await();
         } finally {
             // ------------- cleanup -------------------
@@ -1530,7 +1548,7 @@ public class KafkaTableITCase extends KafkaTableTestBase {
         }
     }
 
-    private String formatOptions() {
+    private String formatOptions(final String format) {
         return String.format("'format' = '%s'", format);
     }
 
