@@ -23,18 +23,19 @@ import org.apache.flink.table.api.Schema;
 import org.apache.flink.table.api.Table;
 import org.apache.flink.table.api.TableResult;
 import org.apache.flink.table.planner.factories.TestValuesTableFactory;
-import org.apache.flink.table.utils.LegacyRowResource;
 import org.apache.flink.types.Row;
+import org.apache.flink.types.RowUtils;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.time.Duration;
 import java.time.LocalDateTime;
 import java.time.ZoneId;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -56,38 +57,42 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.HamcrestCondition.matching;
 
 /** Upsert-kafka IT cases. */
-@RunWith(Parameterized.class)
-public class UpsertKafkaTableITCase extends KafkaTableTestBase {
+class UpsertKafkaTableITCase extends KafkaTableTestBase {
 
-    private static final String JSON_FORMAT = "json";
-    private static final String CSV_FORMAT = "csv";
-    private static final String AVRO_FORMAT = "avro";
-
-    @Parameterized.Parameter public String format;
-
-    @Parameterized.Parameters(name = "format = {0}")
-    public static Object[] parameters() {
-        return new Object[] {JSON_FORMAT, CSV_FORMAT, AVRO_FORMAT};
+    private static Collection<String> formats() {
+        return Arrays.asList("avro", "csv", "json");
     }
 
-    @Rule public final LegacyRowResource usesLegacyRows = LegacyRowResource.INSTANCE;
-
     private static final String USERS_TOPIC = "users";
     private static final String WORD_COUNT_TOPIC = "word_count";
 
-    @Test
-    public void testAggregate() throws Exception {
+    @BeforeEach
+    void setup() {
+        super.setup();
+        RowUtils.USE_LEGACY_TO_STRING = true;
+    }
+
+    @AfterEach
+    void after() {
+        super.after();
+        RowUtils.USE_LEGACY_TO_STRING = false;
+    }
+
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testAggregate(final String format) throws Exception {
         String topic = WORD_COUNT_TOPIC + "_" + format;
         createTestTopic(topic, 4, 1);
         // -------------   test   ---------------
-        wordCountToUpsertKafka(topic);
-        wordFreqToUpsertKafka(topic);
+        wordCountToUpsertKafka(topic, format);
+        wordFreqToUpsertKafka(topic, format);
         // ------------- clean up ---------------
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testTemporalJoin() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testTemporalJoin(final String format) throws Exception {
         String topic = USERS_TOPIC + "_" + format;
         createTestTopic(topic, 2, 1);
         // -------------   test   ---------------
@@ -102,15 +107,16 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         // partition and
         // use the Kafka DefaultPartition to repartition the records.
         env.setParallelism(1);
-        writeChangelogToUpsertKafkaWithMetadata(topic);
+        writeChangelogToUpsertKafkaWithMetadata(topic, format);
         env.setParallelism(2);
-        temporalJoinUpsertKafka(topic);
+        temporalJoinUpsertKafka(topic, format);
         // ------------- clean up ---------------
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testBufferedUpsertSink() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testBufferedUpsertSink(final String format) throws Exception {
         final String topic = "buffered_upsert_topic_" + format;
         createTestTopic(topic, 1, 1);
         String bootstraps = getBootstrapServers();
@@ -198,8 +204,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testBufferedUpsertSinkWithoutAssigningWatermark() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testBufferedUpsertSinkWithoutAssigningWatermark(final String format) throws Exception {
         final String topic = "buffered_upsert_topic_without_assigning_watermark_" + format;
         createTestTopic(topic, 1, 1);
         String bootstraps = getBootstrapServers();
@@ -263,8 +270,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testSourceSinkWithKeyAndPartialValue() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testSourceSinkWithKeyAndPartialValue(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "key_partial_value_topic_" + format;
@@ -361,8 +369,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testKafkaSourceSinkWithKeyAndFullValue() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testKafkaSourceSinkWithKeyAndFullValue(final String format) throws Exception {
         // we always use a different topic name for each parameterized topic,
         // in order to make sure the topic can be created.
         final String topic = "key_full_value_topic_" + format;
@@ -456,8 +465,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testUpsertKafkaSourceSinkWithBoundedSpecificOffsets() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testUpsertKafkaSourceSinkWithBoundedSpecificOffsets(final String format) throws Exception {
         final String topic = "bounded_upsert_" + format + "_" + UUID.randomUUID();
         createTestTopic(topic, 1, 1);
 
@@ -509,8 +519,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    @Test
-    public void testUpsertKafkaSourceSinkWithBoundedTimestamp() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testUpsertKafkaSourceSinkWithBoundedTimestamp(final String format) throws Exception {
         final String topic = "bounded_upsert_" + format + "_" + UUID.randomUUID();
         createTestTopic(topic, 1, 1);
 
@@ -595,8 +606,9 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
      * Tests that setting bounded end offset that is before the earliest offset results in 0
      * results.
      */
-    @Test
-    public void testUpsertKafkaSourceSinkWithZeroLengthBoundedness() throws Exception {
+    @ParameterizedTest(name = "format: {0}")
+    @MethodSource("formats")
+    void testUpsertKafkaSourceSinkWithZeroLengthBoundedness(final String format) throws Exception {
         final String topic = "bounded_upsert_" + format + "_" + UUID.randomUUID();
         createTestTopic(topic, 1, 1);
 
@@ -652,7 +664,7 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         deleteTestTopic(topic);
     }
 
-    private void wordCountToUpsertKafka(String wordCountTable) throws Exception {
+    private void wordCountToUpsertKafka(String wordCountTable, String format) throws Exception {
         String bootstraps = getBootstrapServers();
 
         // ------------- test data ---------------
@@ -765,7 +777,7 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         comparedWithKeyAndOrder(expected2, result2, new int[] {0});
     }
 
-    private void wordFreqToUpsertKafka(String wordCountTable) throws Exception {
+    private void wordFreqToUpsertKafka(String wordCountTable, String format) throws Exception {
         // ------------- test data ---------------
 
         final List<String> expectedData = Arrays.asList("3,1", "2,1");
@@ -802,7 +814,8 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         query.getJobClient().get().cancel();
     }
 
-    private void writeChangelogToUpsertKafkaWithMetadata(String userTable) throws Exception {
+    private void writeChangelogToUpsertKafkaWithMetadata(String userTable, String format)
+            throws Exception {
         String bootstraps = getBootstrapServers();
 
         // ------------- test data ---------------
@@ -1050,7 +1063,7 @@ public class UpsertKafkaTableITCase extends KafkaTableTestBase {
         assertThat(result).satisfies(matching(deepEqualTo(expected, true)));
     }
 
-    private void temporalJoinUpsertKafka(String userTable) throws Exception {
+    private void temporalJoinUpsertKafka(String userTable, String format) throws Exception {
         // ------------- test data ---------------
         List<Row> input =
                 Arrays.asList(
